==> cscec5b-fbxt-impl-3.0.1-20211203.014204-17-sources.jar: com/ejianc/business/fbxt/grap/bean/GrapDetailEntity.java <==
package com.ejianc.business.fbxt.grap.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 进度计量子表实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fbxt_grap_detail")
public class GrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="grap_id")
    private Long grapId; // 主表主键ID
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="info_id")
    private String infoId; // 清单主键
    @TableField(value="info_code")
    private String infoCode; // 清单编码
    @TableField(value="info_name")
    private String infoName; // 清单名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="price")
    private java.math.BigDecimal price; // 无税单价
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 金额
    @TableField(value="pca_amout")
    private java.math.BigDecimal pcaAmout; // 供方完成量
    @TableField(value="amout")
    private java.math.BigDecimal amout; // 审核数量
    @TableField(value="site")
    private String site; // 施工部位 由子表汇总过来

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public BigDecimal getPcaAmout() {
        return pcaAmout;
    }

    public void setPcaAmout(BigDecimal pcaAmout) {
        this.pcaAmout = pcaAmout;
    }

    public BigDecimal getAmout() {
        return amout;
    }

    public void setAmout(BigDecimal amout) {
        this.amout = amout;
    }

    public String getSite() {
        return site;
    }

    public void setSite(String site) {
        this.site = site;
    }



    /**
     * 主表主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 主表主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    
}

==> cscec5b-fbxt-impl-3.0.1-20220303.013330-61-sources.jar: com/ejianc/business/fbxt/grap/bean/GrapDetailEntity.java <==
package com.ejianc.business.fbxt.grap.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 进度计量子表实体
 *
 * @author generator
 *
 */
 @TableName("ejc_fbxt_grap_detail")
public class GrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="grap_id")
    private Long grapId; // 主表主键ID
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="info_id")
    private String infoId; // 清单主键
    @TableField(value="info_code")
    private String infoCode; // 清单编码
    @TableField(value="info_name")
    private String infoName; // 清单名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="price")
    private java.math.BigDecimal price; // 无税单价
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 金额
    @TableField(value="pca_amout")
    private java.math.BigDecimal pcaAmout; // 供方完成量
    @TableField(value="amout")
    private java.math.BigDecimal amout; // 审核数量
    @TableField(value="site")
    private String site; // 施工部位
    @TableField(value = "source_id")//供方清单主键
    private String sourceId;

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public BigDecimal getPcaAmout() {
        return pcaAmout;
    }

    public void setPcaAmout(BigDecimal pcaAmout) {
        this.pcaAmout = pcaAmout;
    }

    public BigDecimal getAmout() {
        return amout;
    }

    public void setAmout(BigDecimal amout) {
        this.amout = amout;
    }

    public String getSite() {
        return site;
    }

    public void setSite(String site) {
        this.site = site;
    }



    /**
     * 主表主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 主表主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }

}
